pub enum Status {
Reported,
NeedsManagerReview,
InvestigationOpen,
CustomerMessageReview,
Resolved,
Closed,
Reopened,
LegalHold,
}Expand description
Review lifecycle for incidents as they move from source report to resolution.
Variants
Reported
Reported incident category for safety and customer follow-up.
NeedsManagerReview
Needs manager review incident category for safety and customer follow-up.
InvestigationOpen
Investigation open incident category for safety and customer follow-up.
CustomerMessageReview
Customer message review incident category for safety and customer follow-up.
Resolved
Owner-pet relationship was matched to a single confident record.
Closed
Closed incident category for safety and customer follow-up.
Reopened
Reopened incident category for safety and customer follow-up.
LegalHold
Legal hold incident category for safety and customer follow-up.